@@ -1,10 +1,14 @@
 import logging
 import os
-import sys, urllib
+import sys
 import msgpack
 import socket
 import threading
-import json
+
+try:
+    import json
+except ImportError:
+    import simplejson as json
 
 from fluent import sender
 
